@@ -66,8 +66,7 @@ class VirtualMachineSnapshot(NamespacedResource):
             wait_timeout=timeout,
             sleep=1,
             exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=lambda: self.instance.get("status", {}).get("readyToUse", None)
-            == status,
+            func=lambda: self.instance.get("status", {}).get("readyToUse") == status,
         )
         for sample in samples:
             if sample:
